/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.osgi.web.jasper.plugins.taglib;

import org.apache.jasper.compiler.tagplugin.TagPlugin;
import org.apache.jasper.compiler.tagplugin.TagPluginContext;

/**
 * @author Preston Crary
 */
public class IfTagPlugin implements TagPlugin {

	@Override
	public void doTag(TagPluginContext tagPluginContext) {
		if (tagPluginContext.isAttributeSpecified("var")) {
			String variableName = tagPluginContext.getTemporaryVariableName();

			tagPluginContext.generateJavaSource("boolean ");
			tagPluginContext.generateJavaSource(variableName);
			tagPluginContext.generateJavaSource(" = ");
			tagPluginContext.generateAttribute("test");
			tagPluginContext.generateJavaSource(";");

			String scope = "PageContext.PAGE_SCOPE";

			if (tagPluginContext.isAttributeSpecified("scope")) {
				String scopeAttribute = tagPluginContext.getConstantAttribute(
					"scope");

				if (scopeAttribute != null) {
					scopeAttribute = scopeAttribute.toLowerCase();

					if (scopeAttribute.equals("application")) {
						scope = "PageContext.APPLICATION_SCOPE";
					}
					else if (scopeAttribute.equals("request")) {
						scope = "PageContext.REQUEST_SCOPE";
					}
					else if (scopeAttribute.equals("session")) {
						scope = "PageContext.SESSION_SCOPE";
					}
				}
			}

			tagPluginContext.generateJavaSource(
				"_jspx_page_tagPluginContext.setAttribute(");
			tagPluginContext.generateAttribute("var");
			tagPluginContext.generateJavaSource(", ");
			tagPluginContext.generateJavaSource(variableName);
			tagPluginContext.generateJavaSource(", ");
			tagPluginContext.generateJavaSource(scope);
			tagPluginContext.generateJavaSource(");");

			tagPluginContext.generateJavaSource("if (");
			tagPluginContext.generateJavaSource(variableName);
		}
		else {
			tagPluginContext.generateJavaSource("if (");
			tagPluginContext.generateAttribute("test");
		}

		tagPluginContext.generateJavaSource(") {");
		tagPluginContext.generateBody();
		tagPluginContext.generateJavaSource("}");
	}

}